@@ -15,6 +15,7 @@ from bleak.assigned_numbers import AdvertisementDataType
 from bleak.backends.device import BLEDevice
 from bleak.backends.scanner import AdvertisementData, AdvertisementDataCallback
 from bleak_retry_connector import restore_discoveries
+from bleak_retry_connector.bluez import stop_discovery
 from bluetooth_adapters import DEFAULT_ADDRESS
 from bluetooth_data_tools import monotonic_time_coarse
 from dbus_fast import InvalidMessageError
@@ -74,11 +75,12 @@ OriginalBleakScanner = bleak.BleakScanner
 
 _LOGGER = logging.getLogger(__name__)
 
+IN_PROGRESS_ERROR = "org.bluez.Error.InProgress"
 
 # If the adapter is in a stuck state the following errors are raised:
 NEED_RESET_ERRORS = [
     "org.bluez.Error.Failed",
-    "org.bluez.Error.InProgress",
+    IN_PROGRESS_ERROR,
     "org.bluez.Error.NotReady",
     "not found",
 ]
@@ -166,6 +168,14 @@ class HaScanner(BaseHaScanner):
     over ethernet, usb over ethernet, etc.
     """
 
+    __slots__ = (
+        "_background_tasks",
+        "_start_future",
+        "_start_stop_lock",
+        "mac_address",
+        "scanner",
+    )
+
     def __init__(
         self,
         mode: BluetoothScanningMode,
@@ -175,15 +185,13 @@ class HaScanner(BaseHaScanner):
         """Init bluetooth discovery."""
         self.mac_address = address
         source = address if address != DEFAULT_ADDRESS else adapter or SOURCE_LOCAL
-        super().__init__(source, adapter)
+        super().__init__(source, adapter, requested_mode=mode)
         self.connectable = True
-        self.requested_mode = mode
         self._start_stop_lock = asyncio.Lock()
         self.scanning = False
         self._background_tasks: set[asyncio.Task[Any]] = set()
         self.scanner: bleak.BleakScanner | None = None
         self._start_future: asyncio.Future[None] | None = None
-        self.current_mode: BluetoothScanningMode | None = None
 
     def _create_background_task(self, coro: Coroutine[Any, Any, None]) -> None:
         """Create a background task and add it to the background tasks set."""
@@ -226,11 +234,7 @@ class HaScanner(BaseHaScanner):
     async def async_diagnostics(self) -> dict[str, Any]:
         """Return diagnostic information about the scanner."""
         base_diag = await super().async_diagnostics()
-        return base_diag | {
-            "adapter": self.adapter,
-            "requested_mode": self.requested_mode,
-            "current_mode": self.current_mode,
-        }
+        return base_diag | {"adapter": self.adapter}
 
     def _async_detection_callback(
         self,
@@ -320,6 +324,7 @@ class HaScanner(BaseHaScanner):
             )
             self.current_mode = BluetoothScanningMode.PASSIVE
 
+        assert self.current_mode is not None  # noqa: S101
         self.scanner = create_bleak_scanner(
             self._async_detection_callback, self.current_mode, self.adapter
         )
@@ -358,6 +363,9 @@ class HaScanner(BaseHaScanner):
         except BleakError as ex:
             await self._async_stop_scanner()
             error_str = str(ex)
+            if IN_PROGRESS_ERROR in error_str:
+                # If discovery is stuck on, try to force stop it
+                await self._async_force_stop_discovery()
             if attempt == 2 and _error_indicates_reset_needed(error_str):
                 await self._async_reset_adapter()
             elif (
@@ -567,3 +575,14 @@ class HaScanner(BaseHaScanner):
             # change the bluetooth dongle.
             _LOGGER.error("%s: Error stopping scanner: %s", self.name, ex)
         self.scanner = None
+
+    async def _async_force_stop_discovery(self) -> None:
+        """Force stop discovery."""
+        _LOGGER.debug("%s: Force stopping bluetooth discovery", self.name)
+        try:
+            async with asyncio.timeout(STOP_TIMEOUT):
+                await stop_discovery(self.adapter)
+        except asyncio.TimeoutError as ex:
+            _LOGGER.error("%s: Timeout force stopping scanner: %s", self.name, ex)
+        except Exception as ex:
+            _LOGGER.error("%s: Failed to force stop scanner: %s", self.name, ex)
